Package 'dmnormLR'

Title: Custom nimble distributions for multivariate normal models that are not full rank
Description: Custom, non-full rank multivariate normal distributions for nimble. Used for penalized splines, etc.
Authors: Devin Johnson [aut, cre]
Maintainer: Devin Johnson <[email protected]>
License: CC0
Version: 0.0.9002
Built: 2026-05-14 21:11:31 UTC
Source: https://github.com/dsjohnson/dmnormLR

Help Index


Custom Multivariate normal distributions for models where the precision matrix is not full rank

Description

Custom Multivariate normal distributions for models where the precision matrix is not full rank

Usage

dmnormLR(x, mean, Q, tau, rank, log = 0)

rmnormLR(n, mean, Q, tau, rank)

Arguments

x

variable

mean

mean vector

Q

Precision matrix, not necessarily full rank

tau

Precision scale parameter

rank

Q matrix rank

log

Return log density

n

Sample size (ignored)

Author(s)

Devin Johnson